function [x2, i] = newton(f, df, x0, delta, N)
% Newton method
% Input parameters:
%   f - single variate function
%   df - the derivative
%   x0 - initial guess
%   delta - terminating condition, threshold of the error
%   N - terminating condition, maximal iteration number
%
% Outputs:
%   x2 - location of the zero point - the solution
%   i - number of iterations

    x1 = x0;
    x2 = x1 - f(x1)/df(x1);
    i = 1;
    while abs(f(x2))>delta && i<=N
        x1 = x2;
        x2 = x1 - f(x1)/df(x1);
        i = i + 1;
    end
end